[![Upload Python Package](https://github.com/jacobtruman/TruMusic/actions/workflows/python-publish.yml/badge.svg)](https://github.com/jacobtruman/TruMusic/actions/workflows/python-publish.yml)

# TruMusic

This is a simple utility to tag audio files with common tags and album art work from last.fm